<?php

namespace Slovocast\Handler\Page;

use Odan\Session\SessionInterface;
use Psr\Http\Message\ResponseInterface as Response;
use Psr\Log\LoggerInterface;
use Slovocast\Domain\Repository\Channel\ChannelRepositoryInterface;
use Slovocast\Domain\Repository\User\UserRepositoryInterface;
use Slovocast\Exception\EntityNotFoundException;
use Slovocast\Handler\Page;

class DashboardPage extends Page 
{
    protected string $template = "dashboard";

    public function __construct(
        protected UserRepositoryInterface $userRepository,
        protected ChannelRepositoryInterface $channelRepository,
        protected SessionInterface $session,
        protected LoggerInterface $logger,
    ) { }

    public function handle(): Response
    {
        $userData = $this->session->get("user");
        $user = $this->userRepository->get($userData['id']);

        try {
            $channel = $this->channelRepository->getFromUser($user);
        } catch (EntityNotFoundException $e) {
            $this->logger->info($e->getMessage(), [
                'user' => $user->getEmail(),
            ]);
            $channel = null;
        }

        $this->pageProps = [ 'channel' => $channel ];
        return parent::handle();
    }
}
